@@ -69,6 +69,10 @@ func (dst *CheCluster) ConvertFrom(srcRaw conversion.Hub) error {
 		return err
 	}
 
+	if err := dst.convertFrom_GitServices(src); err != nil {
+		return err
+	}
+
 	if err := dst.convertFrom_Status(src); err != nil {
 		return err
 	}
@@ -76,6 +80,37 @@ func (dst *CheCluster) ConvertFrom(srcRaw conversion.Hub) error {
 	return nil
 }
 
+func (dst *CheCluster) convertFrom_GitServices(src *chev2.CheCluster) error {
+	for _, github := range src.Spec.GitServices.GitHub {
+		dst.Spec.GitServices.GitHub = append(
+			dst.Spec.GitServices.GitHub,
+			GitHubService{
+				SecretName: github.SecretName,
+				Endpoint:   github.Endpoint,
+			})
+	}
+
+	for _, gitlab := range src.Spec.GitServices.GitLab {
+		dst.Spec.GitServices.GitLab = append(
+			dst.Spec.GitServices.GitLab,
+			GitLabService{
+				SecretName: gitlab.SecretName,
+				Endpoint:   gitlab.Endpoint,
+			})
+	}
+
+	for _, bitbucket := range src.Spec.GitServices.BitBucket {
+		dst.Spec.GitServices.BitBucket = append(
+			dst.Spec.GitServices.BitBucket,
+			BitBucketService{
+				SecretName: bitbucket.SecretName,
+				Endpoint:   bitbucket.Endpoint,
+			})
+	}
+
+	return nil
+}
+
 func (dst *CheCluster) convertFrom_Server(src *chev2.CheCluster) error {
 	dst.Spec.Server.AirGapContainerRegistryHostname = src.Spec.ContainerRegistry.Hostname
 	dst.Spec.Server.AirGapContainerRegistryOrganization = src.Spec.ContainerRegistry.Organization
@@ -91,6 +126,7 @@ func (dst *CheCluster) convertFrom_Server(src *chev2.CheCluster) error {
 		dst.Spec.Server.NonProxyHosts = strings.Join(src.Spec.Components.CheServer.Proxy.NonProxyHosts, "|")
 		dst.Spec.Server.ProxySecret = src.Spec.Components.CheServer.Proxy.CredentialsSecretName
 	}
+	dst.Spec.Server.AllowAutoProvisionUserNamespace = src.Spec.DevEnvironments.DefaultNamespace.AutoProvision
 	dst.Spec.Server.WorkspaceNamespaceDefault = src.Spec.DevEnvironments.DefaultNamespace.Template
 	dst.Spec.Server.WorkspacePodNodeSelector = utils.CloneMap(src.Spec.DevEnvironments.NodeSelector)
 
@@ -349,13 +385,6 @@ func (dst *CheCluster) convertFrom_Database(src *chev2.CheCluster) error {
 }
 
 func (dst *CheCluster) convertFrom_DevWorkspace(src *chev2.CheCluster) error {
-	if src.Spec.Components.DevWorkspace.Deployment != nil {
-		if len(src.Spec.Components.DevWorkspace.Deployment.Containers) != 0 {
-			dst.Spec.DevWorkspace.ControllerImage = src.Spec.Components.DevWorkspace.Deployment.Containers[0].Image
-			dst.Spec.DevWorkspace.Env = src.Spec.Components.DevWorkspace.Deployment.Containers[0].Env
-		}
-	}
-
 	dst.Spec.DevWorkspace.RunningLimit = src.Spec.Components.DevWorkspace.RunningLimit
 	dst.Spec.DevWorkspace.SecondsOfInactivityBeforeIdling = src.Spec.DevEnvironments.SecondsOfInactivityBeforeIdling
 	dst.Spec.DevWorkspace.SecondsOfRunBeforeIdling = src.Spec.DevEnvironments.SecondsOfRunBeforeIdling
