@@ -37,7 +37,7 @@ type CheClusterSpec struct {
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=1
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Development environments"
-	// +kubebuilder:default:={storage: {pvcStrategy: per-user}, defaultNamespace: {template: <username>-devspaces}, secondsOfInactivityBeforeIdling:1800, secondsOfRunBeforeIdling:-1}
+	// +kubebuilder:default:={disableContainerBuildCapabilities: true, defaultComponents: {{name: universal-developer-image, container: {image: "quay.io/devfile/universal-developer-image:ubi8-38da5c2"}}}, defaultEditor: che-incubator/che-code/insiders, storage: {pvcStrategy: per-user}, defaultNamespace: {template: <username>-devspaces, autoProvision: true}, secondsOfInactivityBeforeIdling:1800, secondsOfRunBeforeIdling:-1}
 	DevEnvironments CheClusterDevEnvironments `json:"devEnvironments"`
 	// Che components configuration.
 	// +optional
@@ -45,15 +45,20 @@ type CheClusterSpec struct {
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Components"
 	// +kubebuilder:default:={cheServer: {logLevel: INFO, debug: false}, metrics: {enable: true}, database: {externalDb: false, credentialsSecretName: postgres-credentials, postgresHostName: postgres, postgresPort: "5432", postgresDb: dbche, pvc: {claimSize: "1Gi"}}}
 	Components CheClusterComponents `json:"components"`
-	// Networking, Che authentication, and TLS configuration.
+	// A configuration that allows users to work with remote Git repositories.
 	// +optional
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=3
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Git Services"
+	GitServices CheClusterGitServices `json:"gitServices"`
+	// Networking, Che authentication, and TLS configuration.
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=4
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Networking"
 	// +kubebuilder:default:={auth: {gateway: {configLabels: {app: che, component: che-gateway-config}}}}
 	Networking CheClusterSpecNetworking `json:"networking"`
 	// Configuration of an alternative registry that stores Che images.
 	// +optional
-	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=4
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,order=5
 	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Container registry"
 	ContainerRegistry CheClusterContainerRegistry `json:"containerRegistry"`
 }
@@ -76,7 +81,7 @@ type CheClusterDevEnvironments struct {
 	Tolerations []corev1.Toleration `json:"tolerations,omitempty"`
 	// User's default namespace.
 	// +optional
-	// +kubebuilder:default:={template: <username>-devspaces}
+	// +kubebuilder:default:={template: <username>-devspaces, autoProvision: true}
 	DefaultNamespace DefaultNamespace `json:"defaultNamespace,omitempty"`
 	// Trusted certificate settings.
 	// +optional
@@ -85,10 +90,12 @@ type CheClusterDevEnvironments struct {
 	// The plugin ID must have `publisher/plugin/version` format.
 	// The URI must start from `http://` or `https://`.
 	// +optional
+	// +kubebuilder:default:=che-incubator/che-code/insiders
 	DefaultEditor string `json:"defaultEditor,omitempty"`
 	// Default components applied to DevWorkspaces.
 	// These default components are meant to be used when a Devfile, that does not contain any components.
 	// +optional
+	// +kubebuilder:default:={{name: universal-developer-image, container: {image: "quay.io/devfile/universal-developer-image:ubi8-38da5c2"}}}
 	DefaultComponents []devfile.Component `json:"defaultComponents,omitempty"`
 	// Idle timeout for workspaces in seconds.
 	// This timeout is the duration after which a workspace will be idled if there is no activity.
@@ -100,6 +107,13 @@ type CheClusterDevEnvironments struct {
 	// To disable workspace run timeout, set this value to -1.
 	// +kubebuilder:default:=-1
 	SecondsOfRunBeforeIdling *int32 `json:"secondsOfRunBeforeIdling,omitempty"`
+	// Disables the container build capabilities.
+	// +optional
+	// +kubebuilder:default:=true
+	DisableContainerBuildCapabilities *bool `json:"disableContainerBuildCapabilities,omitempty"`
+	// Container build configuration.
+	// +optional
+	ContainerBuildConfiguration *ContainerBuildConfiguration `json:"containerBuildConfiguration,omitempty"`
 }
 
 // Che components configuration.
@@ -244,7 +258,7 @@ type PluginRegistry struct {
 	ExternalPluginRegistries []ExternalPluginRegistry `json:"externalPluginRegistries,omitempty"`
 	// Open VSX registry URL. If omitted an embedded instance will be used.
 	// +optional
-	OpenVSXURL string `json:"openVSXURL,omitempty"`
+	OpenVSXURL *string `json:"openVSXURL,omitempty"`
 }
 
 // Configuration settings related to the devfile registry used by the Che installation.
@@ -330,9 +344,6 @@ type ImagePuller struct {
 // See https://github.com/devfile/devworkspace-operator
 // +k8s:openapi-gen=true
 type DevWorkspace struct {
-	// Deployment override options.
-	// +optional
-	Deployment *Deployment `json:"deployment,omitempty"`
 	// The maximum number of running workspaces per user.
 	// +optional
 	RunningLimit string `json:"runningLimit,omitempty"`
@@ -345,6 +356,11 @@ type DefaultNamespace struct {
 	// +kubebuilder:default:=<username>-devspaces
 	// +kubebuilder:validation:Pattern=<username>|<userid>
 	Template string `json:"template,omitempty"`
+	// Indicates if is allowed to automatically create a user namespace.
+	// If it set to false, then user namespace must be pre-created by a cluster administrator.
+	// +optional
+	// +kubebuilder:default:=true
+	AutoProvision *bool `json:"autoProvision,omitempty"`
 }
 
 type DashboardHeaderMessage struct {
@@ -445,7 +461,7 @@ type Proxy struct {
 	// URL (protocol+hostname) of the proxy server.
 	// Use only when a proxy configuration is required. The Operator respects OpenShift cluster-wide proxy configuration,
 	// defining `url` in a custom resource leads to overriding the cluster proxy configuration.
-	// See the following page: https://docs.openshift.com/container-platform/4.4/networking/enable-cluster-wide-proxy.html. See also the `proxyPort` and `nonProxyHosts` fields.
+	// See the following page: https://docs.openshift.com/container-platform/4.4/networking/enable-cluster-wide-proxy.html.
 	// +optional
 	Url string `json:"url,omitempty"`
 	// Proxy server port.
@@ -458,7 +474,7 @@ type Proxy struct {
 	//    - 123.42.12.32
 	// Use only when a proxy configuration is required. The Operator respects OpenShift cluster-wide proxy configuration,
 	// defining `nonProxyHosts` in a custom resource leads to merging non-proxy hosts lists from the cluster proxy configuration, and the ones defined in the custom resources.
-	// See the following page: https://docs.openshift.com/container-platform/4.4/networking/enable-cluster-wide-proxy.html. See also the `proxyURL` fields.
+	// See the following page: https://docs.openshift.com/container-platform/4.4/networking/enable-cluster-wide-proxy.html.
 	// +optional
 	NonProxyHosts []string `json:"nonProxyHosts,omitempty"`
 	// The secret name that contains `user` and `password` for a proxy server.
@@ -551,6 +567,78 @@ type PodSecurityContext struct {
 	FsGroup *int64 `json:"fsGroup,omitempty"`
 }
 
+type CheClusterGitServices struct {
+	// Enables users to work with repositories hosted on GitHub (github.com or GitHub Enterprise).
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="GitHub"
+	GitHub []GitHubService `json:"github,omitempty"`
+	// Enables users to work with repositories hosted on GitLab (gitlab.com or self-hosted).
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="GitLab"
+	GitLab []GitLabService `json:"gitlab,omitempty"`
+	// Enables users to work with repositories hosted on Bitbucket (bitbucket.org or self-hosted).
+	// +optional
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,displayName="Bitbucket"
+	BitBucket []BitBucketService `json:"bitbucket,omitempty"`
+}
+
+// GitHubService enables users to work with repositories hosted on GitHub (GitHub.com or GitHub Enterprise).
+type GitHubService struct {
+	// Kubernetes secret, that contains Base64-encoded GitHub OAuth Client id and GitHub OAuth Client secret,
+	// that stored in `id` and `secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-github/.
+	// +kubebuilder:validation:Required
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
+	SecretName string `json:"secretName"`
+	// GitHub server endpoint URL.
+	// +kubebuilder:validation:Required
+	// +kubebuilder:default:="https://github.com"
+	Endpoint string `json:"endpoint"`
+	// Disables subdomain isolation.
+	// +optional
+	DisableSubdomainIsolation *bool `json:"disableSubdomainIsolation,omitempty"`
+}
+
+// GitLabService enables users to work with repositories hosted on GitLab (gitlab.com or self-hosted).
+type GitLabService struct {
+	// Kubernetes secret, that contains Base64-encoded GitHub Application id and GitLab Application Client secret,
+	// that stored in `id` and `secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-gitlab/.
+	// +kubebuilder:validation:Required
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
+	SecretName string `json:"secretName"`
+	// GitLab server endpoint URL.
+	// +kubebuilder:validation:Required
+	// +kubebuilder:default:="https://gitlab.com"
+	Endpoint string `json:"endpoint"`
+}
+
+// BitBucketService enables users to work with repositories hosted on Bitbucket (bitbucket.org or self-hosted).
+type BitBucketService struct {
+	// Kubernetes secret, that contains Base64-encoded Bitbucket OAuth 1.0 or OAuth 2.0 data.
+	// For OAuth 1.0: private key, Bitbucket Application link consumer key and Bitbucket Application link shared secret must be stored
+	// in `private.key`, `consumer.key` and `shared_secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-1-for-a-bitbucket-server/.
+	// For OAuth 2.0: Bitbucket OAuth consumer key and Bitbucket OAuth consumer secret must be stored
+	// in `id` and `secret` keys respectively.
+	// See the following page: https://www.eclipse.org/che/docs/stable/administration-guide/configuring-oauth-2-for-the-bitbucket-cloud/.
+	// +kubebuilder:validation:Required
+	// +operator-sdk:csv:customresourcedefinitions:type=spec,xDescriptors="urn:alm:descriptor:io.kubernetes:Secret"
+	SecretName string `json:"secretName"`
+	// Bitbucket server endpoint URL.
+	// +kubebuilder:validation:Required
+	// +kubebuilder:default:="https://bitbucket.org"
+	Endpoint string `json:"endpoint,omitempty"`
+}
+
+// Container build configuration.
+type ContainerBuildConfiguration struct {
+	// OpenShift security context constraint to build containers.
+	// +kubebuilder:validation:Required
+	// +kubebuilder:default:=container-build
+	OpenShiftSecurityContextConstraint string `json:"openShiftSecurityContextConstraint,omitempty"`
+}
+
 // GatewayPhase describes the different phases of the Che gateway lifecycle.
 type GatewayPhase string
 
@@ -679,10 +767,6 @@ func (c *CheCluster) IsImagePullerSpecEmpty() bool {
 	return c.Spec.Components.ImagePuller.Spec == (imagepullerv1alpha1.KubernetesImagePullerSpec{})
 }
 
-func (c *CheCluster) IsImagePullerImagesEmpty() bool {
-	return len(c.Spec.Components.ImagePuller.Spec.Images) == 0
-}
-
 func (c *CheCluster) GetCheHost() string {
 	if c.Status.CheURL != "" {
 		return strings.TrimPrefix(c.Status.CheURL, "https://")
@@ -720,3 +804,19 @@ func (c *CheCluster) GetIdentityToken() string {
 func (c *CheCluster) IsAccessTokenConfigured() bool {
 	return c.GetIdentityToken() == constants.AccessToken
 }
+
+func (c *CheCluster) IsContainerBuildCapabilitiesEnabled() bool {
+	return c.Spec.DevEnvironments.DisableContainerBuildCapabilities != nil && !*c.Spec.DevEnvironments.DisableContainerBuildCapabilities
+}
+
+func (c *CheCluster) IsOpenShiftSecurityContextConstraintSet() bool {
+	return c.Spec.DevEnvironments.ContainerBuildConfiguration != nil && c.Spec.DevEnvironments.ContainerBuildConfiguration.OpenShiftSecurityContextConstraint != ""
+}
+
+func (c *CheCluster) IsCheFlavor() bool {
+	return os.Getenv("CHE_FLAVOR") == constants.CheFlavor
+}
+
+func (c *CheCluster) IsOpenVSXURLEmpty() bool {
+	return c.Spec.Components.PluginRegistry.OpenVSXURL == nil || *c.Spec.Components.PluginRegistry.OpenVSXURL == ""
+}
