@@ -33,10 +33,13 @@ const (
 	DefaultDashboardCpuRequest    = "100m"
 
 	// PluginRegistry
-	DefaultPluginRegistryMemoryLimit   = "1536Mi"
-	DefaultPluginRegistryMemoryRequest = "32Mi"
-	DefaultPluginRegistryCpuLimit      = "500m"
-	DefaultPluginRegistryCpuRequest    = "100m"
+	DefaultPluginRegistryMemoryLimit                          = "256Mi"
+	DefaultPluginRegistryMemoryLimitEmbeddedOpenVSXRegistry   = "4Gi"
+	DefaultPluginRegistryMemoryRequest                        = "32Mi"
+	DefaultPluginRegistryMemoryRequestEmbeddedOpenVSXRegistry = "512Mi"
+	DefaultPluginRegistryCpuLimit                             = "500m"
+	DefaultPluginRegistryCpuRequest                           = "100m"
+	DefaultOpenVSXUrl                                         = "https://open-vsx.org"
 
 	// DevfileRegistry
 	DefaultDevfileRegistryMemoryLimit   = "256Mi"
@@ -88,10 +91,8 @@ const (
 	CheEclipseOrgMountAs                  = "che.eclipse.org/mount-as"
 	CheEclipseOrgEnvName                  = "che.eclipse.org/env-name"
 	CheEclipseOrgNamespace                = "che.eclipse.org/namespace"
-	CheEclipseOrgGithubOAuthCredentials   = "che.eclipse.org/github-oauth-credentials"
 	CheEclipseOrgOAuthScmServer           = "che.eclipse.org/oauth-scm-server"
 	CheEclipseOrgScmServerEndpoint        = "che.eclipse.org/scm-server-endpoint"
-	CheEclipseOrgHash256                  = "che.eclipse.org/hash256"
 	CheEclipseOrgManagedAnnotationsDigest = "che.eclipse.org/managed-annotations-digest"
 
 	// DevEnvironments
@@ -99,6 +100,7 @@ const (
 	DefaultPvcStorageStrategy      = "per-user"
 	PerWorkspacePVCStorageStrategy = "per-workspace"
 	CommonPVCStorageStrategy       = "common"
+	DefaultAutoProvision           = true
 	DefaultWorkspaceJavaOpts       = "-XX:MaxRAM=150m -XX:MaxRAMFraction=2 -XX:+UseParallelGC " +
 		"-XX:MinHeapFreeRatio=10 -XX:MaxHeapFreeRatio=20 -XX:GCTimeRatio=4 -XX:AdaptiveSizePolicyWeight=90 " +
 		"-Dsun.zip.disableMemoryMapping=true " +
@@ -116,16 +118,19 @@ const (
 	DevfileRegistryName                = "devfile-registry"
 	PluginRegistryName                 = "plugin-registry"
 	PostgresName                       = "postgres"
-	DevWorkspaceController             = "devworkspace-controller"
 	GatewayContainerName               = "gateway"
 	GatewayConfigSideCarContainerName  = "configbump"
 	GatewayAuthenticationContainerName = "oauth-proxy"
 	GatewayAuthorizationContainerName  = "kube-rbac-proxy"
 
 	// common
+	CheFlavor             = "che"
 	CheEclipseOrg         = "che.eclipse.org"
-	DevWorkspaceOperator  = "devworkspace-operator"
 	InstallOrUpdateFailed = "InstallOrUpdateFailed"
+
+	// DevWorkspace
+	DevWorkspaceServiceAccountName = "devworkspace-controller-serviceaccount"
+	DefaultContainerBuildSccName   = "container-build"
 )
 
 var (
