@@ -15,6 +15,7 @@ import (
 	"github.com/eclipse-che/che-operator/pkg/common/constants"
 	"github.com/eclipse-che/che-operator/pkg/common/test"
 	"k8s.io/apimachinery/pkg/api/resource"
+	"k8s.io/utils/pointer"
 
 	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -36,7 +37,21 @@ func TestGetPluginRegistryDeploymentSpec(t *testing.T) {
 
 	testCases := []testCase{
 		{
-			name:          "Test default limits",
+			name:          "Test default limits for embedded OpenVSX registry",
+			initObjects:   []runtime.Object{},
+			memoryLimit:   constants.DefaultPluginRegistryMemoryLimitEmbeddedOpenVSXRegistry,
+			memoryRequest: constants.DefaultPluginRegistryMemoryRequestEmbeddedOpenVSXRegistry,
+			cpuLimit:      constants.DefaultPluginRegistryCpuLimit,
+			cpuRequest:    constants.DefaultPluginRegistryCpuRequest,
+			cheCluster: &chev2.CheCluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Namespace: "eclipse-che",
+					Name:      "eclipse-che",
+				},
+			},
+		},
+		{
+			name:          "Test default limits for external openVSX registry",
 			initObjects:   []runtime.Object{},
 			memoryLimit:   constants.DefaultPluginRegistryMemoryLimit,
 			memoryRequest: constants.DefaultPluginRegistryMemoryRequest,
@@ -47,6 +62,13 @@ func TestGetPluginRegistryDeploymentSpec(t *testing.T) {
 					Namespace: "eclipse-che",
 					Name:      "eclipse-che",
 				},
+				Spec: chev2.CheClusterSpec{
+					Components: chev2.CheClusterComponents{
+						PluginRegistry: chev2.PluginRegistry{
+							OpenVSXURL: pointer.StringPtr("open-vsx-url"),
+						},
+					},
+				},
 			},
 		},
 		{
