@@ -14,6 +14,8 @@ package server
 import (
 	"os"
 
+	"k8s.io/utils/pointer"
+
 	"k8s.io/apimachinery/pkg/api/resource"
 
 	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
@@ -470,3 +472,185 @@ func TestMountGitLabOAuthEnvVar(t *testing.T) {
 		})
 	}
 }
+
+func TestMountGitHubDisableSubdomainIsolationEnvVar(t *testing.T) {
+	type testCase struct {
+		name                              string
+		cheCluster                        *chev2.CheCluster
+		initObjects                       []runtime.Object
+		expectedDisableSubdomainIsolation string
+	}
+
+	testCases := []testCase{
+		{
+			name: "Test #1",
+			cheCluster: &chev2.CheCluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "eclipse-che",
+					Namespace: "eclipse-che",
+				},
+				Spec: chev2.CheClusterSpec{
+					GitServices: chev2.CheClusterGitServices{
+						GitHub: []chev2.GitHubService{
+							{
+								DisableSubdomainIsolation: pointer.BoolPtr(true),
+								SecretName:                "github-oauth-config",
+							},
+						},
+					},
+				},
+			},
+			initObjects: []runtime.Object{
+				&corev1.Secret{
+					TypeMeta: metav1.TypeMeta{
+						Kind:       "Secret",
+						APIVersion: "v1",
+					},
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      "github-oauth-config",
+						Namespace: "eclipse-che",
+						Labels: map[string]string{
+							"app.kubernetes.io/part-of":   "che.eclipse.org",
+							"app.kubernetes.io/component": "oauth-scm-configuration",
+						},
+						Annotations: map[string]string{
+							"che.eclipse.org/oauth-scm-server": "github",
+						},
+					},
+				},
+			},
+			expectedDisableSubdomainIsolation: "true",
+		},
+		{
+			name: "Test #2",
+			cheCluster: &chev2.CheCluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "eclipse-che",
+					Namespace: "eclipse-che",
+				},
+				Spec: chev2.CheClusterSpec{
+					GitServices: chev2.CheClusterGitServices{
+						GitHub: []chev2.GitHubService{
+							{
+								DisableSubdomainIsolation: pointer.BoolPtr(false),
+								SecretName:                "github-oauth-config",
+							},
+						},
+					},
+				},
+			},
+			initObjects: []runtime.Object{
+				&corev1.Secret{
+					TypeMeta: metav1.TypeMeta{
+						Kind:       "Secret",
+						APIVersion: "v1",
+					},
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      "github-oauth-config",
+						Namespace: "eclipse-che",
+						Labels: map[string]string{
+							"app.kubernetes.io/part-of":   "che.eclipse.org",
+							"app.kubernetes.io/component": "oauth-scm-configuration",
+						},
+						Annotations: map[string]string{
+							"che.eclipse.org/oauth-scm-server": "github",
+						},
+					},
+				},
+			},
+			expectedDisableSubdomainIsolation: "false",
+		},
+		{
+			name: "Test #3",
+			cheCluster: &chev2.CheCluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "eclipse-che",
+					Namespace: "eclipse-che",
+				},
+				Spec: chev2.CheClusterSpec{
+					GitServices: chev2.CheClusterGitServices{
+						GitHub: []chev2.GitHubService{
+							{
+								SecretName: "github-oauth-config",
+							},
+						},
+					},
+				},
+			},
+			initObjects: []runtime.Object{
+				&corev1.Secret{
+					TypeMeta: metav1.TypeMeta{
+						Kind:       "Secret",
+						APIVersion: "v1",
+					},
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      "github-oauth-config",
+						Namespace: "eclipse-che",
+						Labels: map[string]string{
+							"app.kubernetes.io/part-of":   "che.eclipse.org",
+							"app.kubernetes.io/component": "oauth-scm-configuration",
+						},
+						Annotations: map[string]string{
+							"che.eclipse.org/oauth-scm-server": "github",
+						},
+					},
+				},
+			},
+			expectedDisableSubdomainIsolation: "",
+		},
+		{
+			name: "Test #4",
+			cheCluster: &chev2.CheCluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "eclipse-che",
+					Namespace: "eclipse-che",
+				},
+				Spec: chev2.CheClusterSpec{
+					GitServices: chev2.CheClusterGitServices{
+						GitHub: []chev2.GitHubService{
+							{
+								SecretName:                "NOT-FOUND-SECRET",
+								DisableSubdomainIsolation: pointer.BoolPtr(true),
+							},
+						},
+					},
+				},
+			},
+			initObjects: []runtime.Object{
+				&corev1.Secret{
+					TypeMeta: metav1.TypeMeta{
+						Kind:       "Secret",
+						APIVersion: "v1",
+					},
+					ObjectMeta: metav1.ObjectMeta{
+						Name:      "github-oauth-config",
+						Namespace: "eclipse-che",
+						Labels: map[string]string{
+							"app.kubernetes.io/part-of":   "che.eclipse.org",
+							"app.kubernetes.io/component": "oauth-scm-configuration",
+						},
+						Annotations: map[string]string{
+							"che.eclipse.org/oauth-scm-server": "github",
+						},
+					},
+				},
+			},
+			expectedDisableSubdomainIsolation: "",
+		},
+	}
+
+	for _, testCase := range testCases {
+		t.Run(testCase.name, func(t *testing.T) {
+			ctx := test.GetDeployContext(testCase.cheCluster, testCase.initObjects)
+
+			server := NewCheServerReconciler()
+			deployment, err := server.getDeploymentSpec(ctx)
+			assert.Nil(t, err, "Unexpected error %v", err)
+
+			container := &deployment.Spec.Template.Spec.Containers[0]
+
+			value := utils.GetEnvByName("CHE_INTEGRATION_GITHUB_DISABLE__SUBDOMAIN__ISOLATION", container.Env)
+			assert.Equal(t, testCase.expectedDisableSubdomainIsolation, value)
+		})
+	}
+}
